=======
AROSICS
=======

An Automated and Robust Open-Source Image Co-Registration Software for Multi-Sensor Satellite Data


* Free software: GNU General Public License v3
* Documentation: http://danschef.gitext.gfz-potsdam.de/arosics/doc/


Status
------

.. .. image:: https://img.shields.io/travis/danschef/arosics.svg
        :target: https://travis-ci.org/danschef/arosics

.. .. image:: https://readthedocs.org/projects/arosics/badge/?version=latest
        :target: https://arosics.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. .. image:: https://pyup.io/repos/github/danschef/arosics/shield.svg
     :target: https://pyup.io/repos/github/danschef/arosics/
     :alt: Updates


.. image:: https://gitext.gfz-potsdam.de/danschef/arosics/badges/master/build.svg
        :target: https://gitext.gfz-potsdam.de/danschef/arosics/commits/master
.. image:: https://gitext.gfz-potsdam.de/danschef/arosics/badges/master/coverage.svg
        :target: http://danschef.gitext.gfz-potsdam.de/arosics/coverage/
.. image:: https://img.shields.io/pypi/v/arosics.svg
        :target: https://pypi.python.org/pypi/arosics

See also the latest coverage_ report.


Features
--------

* TODO


Installation
------------

Use the pip installer:

    pip install arosics


Or clone the repository via GIT and update the PATH environment variable:

    cd /your/installation/folder

    git clone https://gitext.gfz-potsdam.de/danschef/arosics.git

    git clone https://gitext.gfz-potsdam.de/danschef/geoarray.git

    git clone https://gitext.gfz-potsdam.de/danschef/py_tools_ds.git

    PATH=$PATH:/path/to/your/installation/folder/arosics:/path/to/your/installation/folder/geoarray:/path/to/your/installation/folder/py_tools_ds


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _coverage: http://danschef.gitext.gfz-potsdam.de/arosics/coverage/

